fastquat.Quaternion
===================

.. currentmodule:: fastquat

.. autoclass:: Quaternion


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~Quaternion.__init__
      ~Quaternion.block_until_ready
      ~Quaternion.conj
      ~Quaternion.conjugate
      ~Quaternion.devices
      ~Quaternion.exp
      ~Quaternion.flatten
      ~Quaternion.from_array
      ~Quaternion.from_rotation_matrix
      ~Quaternion.from_scalar_vector
      ~Quaternion.full
      ~Quaternion.log
      ~Quaternion.norm
      ~Quaternion.normalize
      ~Quaternion.ones
      ~Quaternion.random
      ~Quaternion.ravel
      ~Quaternion.reshape
      ~Quaternion.rotate_vector
      ~Quaternion.slerp
      ~Quaternion.squeeze
      ~Quaternion.to_components
      ~Quaternion.to_rotation_matrix
      ~Quaternion.tree_flatten
      ~Quaternion.tree_unflatten
      ~Quaternion.zeros





   .. rubric:: Attributes

   .. autosummary::

      ~Quaternion.device
      ~Quaternion.dtype
      ~Quaternion.itemsize
      ~Quaternion.nbytes
      ~Quaternion.ndim
      ~Quaternion.shape
      ~Quaternion.size
      ~Quaternion.vector
      ~Quaternion.w
      ~Quaternion.x
      ~Quaternion.y
      ~Quaternion.z
